import React__default, { createElement } from 'react';
import { createUseStyles, jss } from 'react-jss';
import clsx from 'clsx';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var useStepperStyles =
/*#__PURE__*/
createUseStyles({
  StepperContainer: {
    display: 'flex',
    alignItems: 'flex-start',
    flexDirection: 'row',
    padding: 24,
    fontFamily: 'Arial, Helvetica, sans-serif'
  },
  StepContainer: {
    flex: 1,
    position: 'relative',
    paddingLeft: 8,
    paddingRight: 8
  }
});
var stepStyleDefaults = {
  activeBgColor: '#ed1d24',
  activeTextColor: '#ffffff',
  completedBgColor: '#a10308',
  completedTextColor: '#ffffff',
  inactiveBgColor: '#e0e0e0',
  inactiveTextColor: '#ffffff',
  size: '2em',
  circleFontSize: '1rem',
  labelFontSize: '0.875rem',
  borderRadius: '50%',
  fontWeight: 500
};
var useStepStyles =
/*#__PURE__*/
createUseStyles({
  StepMain: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  },
  StepCircle: function StepCircle(props) {
    return {
      borderRadius: props.borderRadius,
      backgroundColor: props.inactiveBgColor,
      width: props.size,
      height: props.size,
      fontSize: '1em',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      '&.active': {
        backgroundColor: props.activeBgColor
      },
      '&.completed': {
        backgroundColor: props.completedBgColor
      }
    };
  },
  StepButton: {
    border: 'none',
    margin: 0,
    padding: 0,
    cursor: 'pointer'
  },
  StepCircleContent: function StepCircleContent(props) {
    return {
      color: props.inactiveTextColor,
      fontSize: props.circleFontSize,
      fontVariantNumeric: 'tabular-nums',
      '&.active': {
        color: props.activeTextColor
      },
      '&.completed': {
        color: props.completedTextColor
      }
    };
  },
  LabelContainer: function LabelContainer(props) {
    return {
      width: '100%',
      fontSize: props.labelFontSize,
      fontWeight: 400,
      lineHeight: 1.4
    };
  },
  Label: function Label(props) {
    return {
      display: 'block',
      marginTop: 16,
      textAlign: 'center',
      fontWeight: props.fontWeight
    };
  }
});
var connectorStyleDefaults = {
  disabledColor: '#bdbdbd',
  activeColor: '#ed1d24',
  completedColor: '#a10308',
  size: 1,
  style: 'solid'
};
var useConnectorStyles =
/*#__PURE__*/
createUseStyles({
  ConnectorContainer: function ConnectorContainer(props) {
    return {
      top: "calc((" + props.stepSize + " - " + props.size + ") / 2)",
      left: "calc(-50% + " + props.stepSize + " - 8px)",
      right: "calc(50% + " + props.stepSize + " - 8px)",
      position: 'absolute'
    };
  },
  Connector: function Connector(props) {
    return {
      borderTopStyle: props.style,
      borderTopWidth: props.size,
      borderColor: props.disabledColor,
      display: 'block',
      '&.completed': {
        borderColor: props.completedColor
      },
      '&.active': {
        borderColor: props.activeColor
      }
    };
  }
});

var Step = function Step(_ref) {
  var children = _ref.children,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      styleConfig = _ref.styleConfig,
      _ref$completed = _ref.completed,
      completed = _ref$completed === void 0 ? false : _ref$completed,
      _ref$active = _ref.active,
      active = _ref$active === void 0 ? false : _ref$active,
      className = _ref.className,
      rest = _objectWithoutPropertiesLoose(_ref, ["children", "label", "styleConfig", "completed", "active", "className"]);

  var stepStyleProps = _extends({}, styleConfig, {
    completed: completed,
    active: active
  });

  var classes = useStepStyles(_extends({}, stepStyleDefaults, {
    circleFontSize: "calc(" + stepStyleProps.size + " / 2)"
  }, stepStyleProps));
  return createElement("div", {
    className: classes.StepMain
  }, createElement("button", Object.assign({
    disabled: !active && !completed,
    className: clsx(classes.StepCircle, classes.StepButton, {
      active: active
    }, {
      completed: completed
    }, className)
  }, rest), createElement("span", {
    className: clsx(classes.StepCircleContent, {
      active: active
    }, {
      completed: completed
    })
  }, children)), label && createElement("div", {
    className: classes.LabelContainer
  }, createElement("span", {
    className: classes.Label
  }, label)));
};

var Connector = function Connector(_ref) {
  var _ref$completed = _ref.completed,
      completed = _ref$completed === void 0 ? false : _ref$completed,
      _ref$active = _ref.active,
      active = _ref$active === void 0 ? false : _ref$active,
      _ref$stateColors = _ref.stateColors,
      stateColors = _ref$stateColors === void 0 ? false : _ref$stateColors,
      connectorStyle = _ref.connectorStyle;

  var convertNumericToPixel = function convertNumericToPixel(object, property) {
    if (typeof object[property] === 'number') {
      object[property] = object[property] + "px";
    }
  };

  convertNumericToPixel(connectorStyle, 'stepSize');
  convertNumericToPixel(connectorStyle, 'size');
  var classes = useConnectorStyles(connectorStyle);
  return React__default.createElement("div", {
    className: classes.ConnectorContainer
  }, React__default.createElement("span", {
    className: clsx(classes.Connector, {
      completed: completed && stateColors
    }, {
      active: active && stateColors
    })
  }));
};

var generateId = function generateId(rule) {
  return "RFS-" + rule.key;
};

var createGenerateId = function createGenerateId() {
  return generateId;
};

jss.setup({
  createGenerateId: createGenerateId
});

var Stepper = function Stepper(_ref) {
  var steps = _ref.steps,
      children = _ref.children,
      _ref$connectorStateCo = _ref.connectorStateColors,
      connectorStateColors = _ref$connectorStateCo === void 0 ? false : _ref$connectorStateCo,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$stepClassName = _ref.stepClassName,
      stepClassName = _ref$stepClassName === void 0 ? '' : _ref$stepClassName,
      _ref$activeStep = _ref.activeStep,
      activeStep = _ref$activeStep === void 0 ? 0 : _ref$activeStep,
      styleConfig = _ref.styleConfig,
      connectorStyleConfig = _ref.connectorStyleConfig;
  var classes = useStepperStyles();

  var generateStepProps = function generateStepProps(index, activeStep) {
    return {
      className: stepClassName,
      children: index,
      completed: index < activeStep,
      active: index === activeStep,
      styleConfig: styleConfig
    };
  };

  var useStepsProp = steps instanceof Array && steps.length > 0;
  var stepsArray = useStepsProp ? steps : React__default.Children.toArray(children);
  var stepsToRender = stepsArray.map(function (step, index) {
    if (!useStepsProp && !React__default.isValidElement(step)) return null;
    var stepProps = generateStepProps(index, activeStep);
    return React__default.createElement("div", {
      key: index,
      className: classes.StepContainer
    }, index !== 0 && React__default.createElement(Connector, {
      completed: stepProps.completed,
      active: stepProps.active,
      stateColors: connectorStateColors,
      connectorStyle: _extends({}, connectorStyleDefaults, {}, connectorStyleConfig, {
        stepSize: styleConfig && styleConfig.size || stepStyleDefaults.size
      })
    }), React__default.isValidElement(step) ? React__default.cloneElement(step, _extends({}, stepProps, {}, step.props)) : React__default.createElement(Step, Object.assign({}, stepProps, step)));
  });
  return React__default.createElement("div", {
    className: clsx(classes.StepperContainer, className)
  }, stepsToRender);
};

export { Step, Stepper };
//# sourceMappingURL=react-form-stepper.esm.js.map
